@@ -13,15 +13,27 @@
 #include "esphome/components/openthread/openthread.h"
 #endif
 
+#ifdef USE_MODEM
+#include "esphome/components/modem/modem_component.h"
+#endif
+
 namespace esphome {
 namespace network {
 
+// The order of the components is important: WiFi should come after any possible main interfaces (it may be used as
+// an AP that use a previous interface for NAT).
+
 bool is_connected() {
 #ifdef USE_ETHERNET
   if (ethernet::global_eth_component != nullptr && ethernet::global_eth_component->is_connected())
     return true;
 #endif
 
+#ifdef USE_MODEM
+  if (modem::global_modem_component != nullptr)
+    return modem::global_modem_component->is_connected();
+#endif
+
 #ifdef USE_WIFI
   if (wifi::global_wifi_component != nullptr)
     return wifi::global_wifi_component->is_connected();
@@ -39,6 +51,11 @@ bool is_connected() {
 }
 
 bool is_disabled() {
+#ifdef USE_MODEM
+  if (modem::global_modem_component != nullptr)
+    return modem::global_modem_component->is_disabled();
+#endif
+
 #ifdef USE_WIFI
   if (wifi::global_wifi_component != nullptr)
     return wifi::global_wifi_component->is_disabled();
@@ -51,6 +68,12 @@ network::IPAddresses get_ip_addresses() {
   if (ethernet::global_eth_component != nullptr)
     return ethernet::global_eth_component->get_ip_addresses();
 #endif
+
+#ifdef USE_MODEM
+  if (modem::global_modem_component != nullptr)
+    return modem::global_modem_component->get_ip_addresses();
+#endif
+
 #ifdef USE_WIFI
   if (wifi::global_wifi_component != nullptr)
     return wifi::global_wifi_component->get_ip_addresses();
@@ -67,6 +90,12 @@ std::string get_use_address() {
   if (ethernet::global_eth_component != nullptr)
     return ethernet::global_eth_component->get_use_address();
 #endif
+
+#ifdef USE_MODEM
+  if (modem::global_modem_component != nullptr)
+    return modem::global_modem_component->get_use_address();
+#endif
+
 #ifdef USE_WIFI
   if (wifi::global_wifi_component != nullptr)
     return wifi::global_wifi_component->get_use_address();
