@@ -273,7 +273,7 @@ CONFIG_SCHEMA = PIPSOLAR_COMPONENT_SCHEMA.extend(
 async def to_code(config):
     paren = await cg.get_variable(config[CONF_PIPSOLAR_ID])
 
-    for type, _ in TYPES.items():
+    for type in TYPES:
         if type in config:
             conf = config[type]
             sens = await sensor.new_sensor(conf)
