@@ -107,7 +107,7 @@ void SelectCall::perform() {
     }
   }
 
-  if (std::find(options.begin(), options.end(), target_value) == options.end()) {
+  if (!parent->has_option(target_value)) {
     ESP_LOGW(TAG, "'%s' - Option %s is not a valid option", name, target_value.c_str());
     return;
   }
