@@ -1,9 +1,9 @@
 import esphome.codegen as cg
-import esphome.config_validation as cv
 from esphome.components import binary_sensor
-from esphome.const import CONF_ROW, CONF_COL
+import esphome.config_validation as cv
+from esphome.const import CONF_COL, CONF_ROW
 
-from .. import SX1509Component, sx1509_ns, CONF_SX1509_ID
+from .. import CONF_SX1509_ID, SX1509Component, sx1509_ns
 
 DEPENDENCIES = ["sx1509"]
 
