@@ -15,7 +15,7 @@ void TemplateText::setup() {
   if (!this->pref_) {
     ESP_LOGD(TAG, "State from initial: %s", value.c_str());
   } else {
-    uint32_t key = this->get_object_id_hash();
+    uint32_t key = this->get_preference_hash();
     key += this->traits.get_min_length() << 2;
     key += this->traits.get_max_length() << 4;
     key += fnv1_hash(this->traits.get_pattern()) << 6;
