@@ -130,7 +130,7 @@ inline std::string operator+(const StringRef &lhs, const char *rhs) {
 
 #ifdef USE_JSON
 // NOLINTNEXTLINE(readability-identifier-naming)
-void convertToJson(const StringRef &src, JsonVariant dst);
+inline void convertToJson(const StringRef &src, JsonVariant dst) { dst.set(src.c_str()); }
 #endif  // USE_JSON
 
 }  // namespace esphome
